# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVoedingskabelAdersEnSectie(KeuzelijstField):
    """Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een voedingskabel volgens het aantal aders en hun dikte in vierkante millimeter."""
    naam = 'KlVoedingskabelAdersEnSectie'
    label = 'Voedingskabel aders en sectie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVoedingskabelAdersEnSectie'
    definition = 'Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een voedingskabel volgens het aantal aders en hun dikte in vierkante millimeter.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVoedingskabelAdersEnSectie'
    options = {
        '1-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='1-x-1.5-mm2',
                                        label='1 x 1.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-1.5-mm2'),
        '1-x-10-mm2': KeuzelijstWaarde(invulwaarde='1-x-10-mm2',
                                       label='1 x 10 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-10-mm2'),
        '1-x-16-mm2': KeuzelijstWaarde(invulwaarde='1-x-16-mm2',
                                       label='1 x 16 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-16-mm2'),
        '1-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='1-x-2.5-mm2',
                                        label='1 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-2.5-mm2'),
        '1-x-25-mm2': KeuzelijstWaarde(invulwaarde='1-x-25-mm2',
                                       label='1 x 25 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-25-mm2'),
        '1-x-4-mm2': KeuzelijstWaarde(invulwaarde='1-x-4-mm2',
                                      label='1 x 4 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-4-mm2'),
        '1-x-6-mm2': KeuzelijstWaarde(invulwaarde='1-x-6-mm2',
                                      label='1 x 6 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-6-mm2'),
        '1.5': KeuzelijstWaarde(invulwaarde='1.5',
                                label='1.5',
                                status='ingebruik',
                                definitie='1.5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1.5'),
        '16': KeuzelijstWaarde(invulwaarde='16',
                               label='16',
                               status='ingebruik',
                               definitie='16',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/16'),
        '19x1.5': KeuzelijstWaarde(invulwaarde='19x1.5',
                                   label='19x1.5',
                                   status='ingebruik',
                                   definitie='19x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/19x1.5'),
        '1x2.5': KeuzelijstWaarde(invulwaarde='1x2.5',
                                  label='1x2.5',
                                  status='ingebruik',
                                  definitie='1x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1x2.5'),
        '25': KeuzelijstWaarde(invulwaarde='25',
                               label='25',
                               status='ingebruik',
                               definitie='25',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/25'),
        '27x1.5': KeuzelijstWaarde(invulwaarde='27x1.5',
                                   label='27x1.5',
                                   status='ingebruik',
                                   definitie='27x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/27x1.5'),
        '2x1.5': KeuzelijstWaarde(invulwaarde='2x1.5',
                                  label='2x1.5',
                                  status='ingebruik',
                                  definitie='2x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x1.5'),
        '2x2.5': KeuzelijstWaarde(invulwaarde='2x2.5',
                                  label='2x2.5',
                                  status='ingebruik',
                                  definitie='2x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x2.5'),
        '2x2.5-2.5': KeuzelijstWaarde(invulwaarde='2x2.5-2.5',
                                      label='2x2.5+2.5',
                                      status='ingebruik',
                                      definitie='2x2.5+2.5',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x2.5-2.5'),
        '2x25-16': KeuzelijstWaarde(invulwaarde='2x25-16',
                                    label='2x25+16',
                                    status='ingebruik',
                                    definitie='2x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x25-16'),
        '2x4': KeuzelijstWaarde(invulwaarde='2x4',
                                label='2x4',
                                status='ingebruik',
                                definitie='2x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x4'),
        '3-x-10-6-mm2': KeuzelijstWaarde(invulwaarde='3-x-10-6-mm2',
                                         label='3 x 10+6 mm²',
                                         status='uitgebruik',
                                         definitie='uitgebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-10-6-mm2'),
        '3-x-16-10-mm2': KeuzelijstWaarde(invulwaarde='3-x-16-10-mm2',
                                          label='3 x 16+10 mm²',
                                          status='uitgebruik',
                                          definitie='uitgebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-16-10-mm2'),
        '3-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='3-x-2.5-mm2',
                                        label='3 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-2.5-mm2'),
        '3-x-25---1-x-16-mm2': KeuzelijstWaarde(invulwaarde='3-x-25---1-x-16-mm2',
                                                label='3 x 25 + 1 x 16 mm²',
                                                status='uitgebruik',
                                                definitie='uitgebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-25---1-x-16-mm2'),
        '3-x-25-16-mm2': KeuzelijstWaarde(invulwaarde='3-x-25-16-mm2',
                                          label='3 x 25+16 mm²',
                                          status='uitgebruik',
                                          definitie='uitgebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-25-16-mm2'),
        '3-x-35-25-mm2': KeuzelijstWaarde(invulwaarde='3-x-35-25-mm2',
                                          label='3 x 35+25 mm²',
                                          status='uitgebruik',
                                          definitie='uitgebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-35-25-mm2'),
        '30x1.5': KeuzelijstWaarde(invulwaarde='30x1.5',
                                   label='30x1.5',
                                   status='ingebruik',
                                   definitie='30x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/30x1.5'),
        '37x1.5': KeuzelijstWaarde(invulwaarde='37x1.5',
                                   label='37x1.5',
                                   status='ingebruik',
                                   definitie='37x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/37x1.5'),
        '3g1.5': KeuzelijstWaarde(invulwaarde='3g1.5',
                                  label='3G1.5',
                                  status='ingebruik',
                                  definitie='3G1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g1.5'),
        '3g10': KeuzelijstWaarde(invulwaarde='3g10',
                                 label='3G10',
                                 status='ingebruik',
                                 definitie='3G10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g10'),
        '3g2': KeuzelijstWaarde(invulwaarde='3g2',
                                label='3G2',
                                status='ingebruik',
                                definitie='3G2',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2'),
        '3g2.5': KeuzelijstWaarde(invulwaarde='3g2.5',
                                  label='3G2.5',
                                  status='ingebruik',
                                  definitie='3G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2.5'),
        '3g2.5-mm2': KeuzelijstWaarde(invulwaarde='3g2.5-mm2',
                                      label='3G2.5 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2.5-mm2'),
        '3g2x5': KeuzelijstWaarde(invulwaarde='3g2x5',
                                  label='3G2x5',
                                  status='ingebruik',
                                  definitie='3G2x5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2x5'),
        '3g4': KeuzelijstWaarde(invulwaarde='3g4',
                                label='3G4',
                                status='ingebruik',
                                definitie='3G4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g4'),
        '3x1.5': KeuzelijstWaarde(invulwaarde='3x1.5',
                                  label='3x1.5',
                                  status='ingebruik',
                                  definitie='3x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x1.5'),
        '3x10-10': KeuzelijstWaarde(invulwaarde='3x10-10',
                                    label='3x10+10',
                                    status='ingebruik',
                                    definitie='3x10+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x10-10'),
        '3x10-16': KeuzelijstWaarde(invulwaarde='3x10-16',
                                    label='3x10+16',
                                    status='ingebruik',
                                    definitie='3x10+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x10-16'),
        '3x10-6': KeuzelijstWaarde(invulwaarde='3x10-6',
                                   label='3x10+6',
                                   status='ingebruik',
                                   definitie='3x10+6',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x10-6'),
        '3x16-10': KeuzelijstWaarde(invulwaarde='3x16-10',
                                    label='3x16+10',
                                    status='ingebruik',
                                    definitie='3x16+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x16-10'),
        '3x16-16': KeuzelijstWaarde(invulwaarde='3x16-16',
                                    label='3x16+16',
                                    status='ingebruik',
                                    definitie='3x16+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x16-16'),
        '3x2.5': KeuzelijstWaarde(invulwaarde='3x2.5',
                                  label='3x2.5',
                                  status='ingebruik',
                                  definitie='3x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x2.5'),
        '3x2.5-16': KeuzelijstWaarde(invulwaarde='3x2.5-16',
                                     label='3x2.5+16',
                                     status='ingebruik',
                                     definitie='3x2.5+16',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x2.5-16'),
        '3x25': KeuzelijstWaarde(invulwaarde='3x25',
                                 label='3x25',
                                 status='ingebruik',
                                 definitie='3x25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25'),
        '3x25-10': KeuzelijstWaarde(invulwaarde='3x25-10',
                                    label='3x25+10',
                                    status='ingebruik',
                                    definitie='3x25+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-10'),
        '3x25-15': KeuzelijstWaarde(invulwaarde='3x25-15',
                                    label='3x25+15',
                                    status='ingebruik',
                                    definitie='3x25+15',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-15'),
        '3x25-16': KeuzelijstWaarde(invulwaarde='3x25-16',
                                    label='3x25+16',
                                    status='ingebruik',
                                    definitie='3x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-16'),
        '3x25-25': KeuzelijstWaarde(invulwaarde='3x25-25',
                                    label='3x25+25',
                                    status='ingebruik',
                                    definitie='3x25+25',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-25'),
        '3x25-6': KeuzelijstWaarde(invulwaarde='3x25-6',
                                   label='3x25+6',
                                   status='ingebruik',
                                   definitie='3x25+6',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-6'),
        '3x35-16': KeuzelijstWaarde(invulwaarde='3x35-16',
                                    label='3x35+16',
                                    status='ingebruik',
                                    definitie='3x35+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x35-16'),
        '3x35-25': KeuzelijstWaarde(invulwaarde='3x35-25',
                                    label='3x35+25',
                                    status='ingebruik',
                                    definitie='3x35+25',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x35-25'),
        '3x50-25': KeuzelijstWaarde(invulwaarde='3x50-25',
                                    label='3x50+25',
                                    status='ingebruik',
                                    definitie='3x50+25',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x50-25'),
        '3x95-50': KeuzelijstWaarde(invulwaarde='3x95-50',
                                    label='3x95+50',
                                    status='ingebruik',
                                    definitie='3x95+50',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x95-50'),
        '4-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='4-x-1.5-mm2',
                                        label='4 x 1.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-1.5-mm2'),
        '4-x-10-mm2': KeuzelijstWaarde(invulwaarde='4-x-10-mm2',
                                       label='4 x 10 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-10-mm2'),
        '4-x-150-mm2': KeuzelijstWaarde(invulwaarde='4-x-150-mm2',
                                        label='4 x 150 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-150-mm2'),
        '4-x-16-mm2': KeuzelijstWaarde(invulwaarde='4-x-16-mm2',
                                       label='4 x 16 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-16-mm2'),
        '4-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='4-x-2.5-mm2',
                                        label='4 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-2.5-mm2'),
        '4-x-25-mm2': KeuzelijstWaarde(invulwaarde='4-x-25-mm2',
                                       label='4 x 25 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-25-mm2'),
        '4-x-35-mm2': KeuzelijstWaarde(invulwaarde='4-x-35-mm2',
                                       label='4 x 35 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-35-mm2'),
        '4-x-4-mm2': KeuzelijstWaarde(invulwaarde='4-x-4-mm2',
                                      label='4 x 4 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-4-mm2'),
        '4-x-50-mm2': KeuzelijstWaarde(invulwaarde='4-x-50-mm2',
                                       label='4 x 50 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-50-mm2'),
        '4-x-6-mm2': KeuzelijstWaarde(invulwaarde='4-x-6-mm2',
                                      label='4 x 6 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-6-mm2'),
        '4-x-95-mm2': KeuzelijstWaarde(invulwaarde='4-x-95-mm2',
                                       label='4 x 95 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-95-mm2'),
        '48x1.5': KeuzelijstWaarde(invulwaarde='48x1.5',
                                   label='48x1.5',
                                   status='ingebruik',
                                   definitie='48x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/48x1.5'),
        '49x1.5': KeuzelijstWaarde(invulwaarde='49x1.5',
                                   label='49x1.5',
                                   status='ingebruik',
                                   definitie='49x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/49x1.5'),
        '4g10': KeuzelijstWaarde(invulwaarde='4g10',
                                 label='4G10',
                                 status='ingebruik',
                                 definitie='4G10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g10'),
        '4g16': KeuzelijstWaarde(invulwaarde='4g16',
                                 label='4G16',
                                 status='ingebruik',
                                 definitie='4G16',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g16'),
        '4g2.5': KeuzelijstWaarde(invulwaarde='4g2.5',
                                  label='4G2.5',
                                  status='ingebruik',
                                  definitie='4G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g2.5'),
        '4g25': KeuzelijstWaarde(invulwaarde='4g25',
                                 label='4G25',
                                 status='ingebruik',
                                 definitie='4G25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g25'),
        '4g35': KeuzelijstWaarde(invulwaarde='4g35',
                                 label='4G35',
                                 status='ingebruik',
                                 definitie='4G35',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g35'),
        '4g4': KeuzelijstWaarde(invulwaarde='4g4',
                                label='4G4',
                                status='ingebruik',
                                definitie='4G4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g4'),
        '4g6': KeuzelijstWaarde(invulwaarde='4g6',
                                label='4G6',
                                status='ingebruik',
                                definitie='4G6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g6'),
        '4x1.5': KeuzelijstWaarde(invulwaarde='4x1.5',
                                  label='4x1.5',
                                  status='ingebruik',
                                  definitie='4x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x1.5'),
        '4x10': KeuzelijstWaarde(invulwaarde='4x10',
                                 label='4x10',
                                 status='ingebruik',
                                 definitie='4x10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x10'),
        '4x10-16': KeuzelijstWaarde(invulwaarde='4x10-16',
                                    label='4x10+16',
                                    status='ingebruik',
                                    definitie='4x10+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x10-16'),
        '4x150': KeuzelijstWaarde(invulwaarde='4x150',
                                  label='4x150',
                                  status='ingebruik',
                                  definitie='4x150',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x150'),
        '4x16': KeuzelijstWaarde(invulwaarde='4x16',
                                 label='4x16',
                                 status='ingebruik',
                                 definitie='4x16',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x16'),
        '4x16-10': KeuzelijstWaarde(invulwaarde='4x16-10',
                                    label='4x16+10',
                                    status='ingebruik',
                                    definitie='4x16+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x16-10'),
        '4x16-16': KeuzelijstWaarde(invulwaarde='4x16-16',
                                    label='4x16+16',
                                    status='ingebruik',
                                    definitie='4x16+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x16-16'),
        '4x2.5': KeuzelijstWaarde(invulwaarde='4x2.5',
                                  label='4x2.5',
                                  status='ingebruik',
                                  definitie='4x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2.5'),
        '4x2.5-16': KeuzelijstWaarde(invulwaarde='4x2.5-16',
                                     label='4x2.5+16',
                                     status='ingebruik',
                                     definitie='4x2.5+16',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2.5-16'),
        '4x2.5-2.5': KeuzelijstWaarde(invulwaarde='4x2.5-2.5',
                                      label='4x2.5+2.5',
                                      status='ingebruik',
                                      definitie='4x2.5+2.5',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2.5-2.5'),
        '4x25': KeuzelijstWaarde(invulwaarde='4x25',
                                 label='4x25',
                                 status='ingebruik',
                                 definitie='4x25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x25'),
        '4x25-16': KeuzelijstWaarde(invulwaarde='4x25-16',
                                    label='4x25+16',
                                    status='ingebruik',
                                    definitie='4x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x25-16'),
        '4x25-2.5': KeuzelijstWaarde(invulwaarde='4x25-2.5',
                                     label='4x25+2.5',
                                     status='ingebruik',
                                     definitie='4x25+2.5',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x25-2.5'),
        '4x2x0.8': KeuzelijstWaarde(invulwaarde='4x2x0.8',
                                    label='4x2x0.8',
                                    status='ingebruik',
                                    definitie='4x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2x0.8'),
        '4x35': KeuzelijstWaarde(invulwaarde='4x35',
                                 label='4x35',
                                 status='ingebruik',
                                 definitie='4x35',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x35'),
        '4x4': KeuzelijstWaarde(invulwaarde='4x4',
                                label='4x4',
                                status='ingebruik',
                                definitie='4x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x4'),
        '4x50': KeuzelijstWaarde(invulwaarde='4x50',
                                 label='4x50',
                                 status='ingebruik',
                                 definitie='4x50',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x50'),
        '4x6': KeuzelijstWaarde(invulwaarde='4x6',
                                label='4x6',
                                status='ingebruik',
                                definitie='4x6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x6'),
        '4x6-16': KeuzelijstWaarde(invulwaarde='4x6-16',
                                   label='4x6+16',
                                   status='ingebruik',
                                   definitie='4x6+16',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x6-16'),
        '4x70': KeuzelijstWaarde(invulwaarde='4x70',
                                 label='4x70',
                                 status='ingebruik',
                                 definitie='4x70',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x70'),
        '5-x-10-mm2': KeuzelijstWaarde(invulwaarde='5-x-10-mm2',
                                       label='5 x 10 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5-x-10-mm2'),
        '5-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='5-x-2.5-mm2',
                                        label='5 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5-x-2.5-mm2'),
        '5g1.5': KeuzelijstWaarde(invulwaarde='5g1.5',
                                  label='5G1.5',
                                  status='ingebruik',
                                  definitie='5G1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g1.5'),
        '5g10': KeuzelijstWaarde(invulwaarde='5g10',
                                 label='5G10',
                                 status='ingebruik',
                                 definitie='5G10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g10'),
        '5g16': KeuzelijstWaarde(invulwaarde='5g16',
                                 label='5G16',
                                 status='ingebruik',
                                 definitie='5G16',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g16'),
        '5g2.5': KeuzelijstWaarde(invulwaarde='5g2.5',
                                  label='5G2.5',
                                  status='ingebruik',
                                  definitie='5G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g2.5'),
        '5g4': KeuzelijstWaarde(invulwaarde='5g4',
                                label='5G4',
                                status='ingebruik',
                                definitie='5G4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g4'),
        '5g6': KeuzelijstWaarde(invulwaarde='5g6',
                                label='5G6',
                                status='ingebruik',
                                definitie='5G6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g6'),
        '5x2.5': KeuzelijstWaarde(invulwaarde='5x2.5',
                                  label='5x2.5',
                                  status='ingebruik',
                                  definitie='5x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5x2.5'),
        '5x4': KeuzelijstWaarde(invulwaarde='5x4',
                                label='5x4',
                                status='ingebruik',
                                definitie='5x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5x4'),
        '5x6': KeuzelijstWaarde(invulwaarde='5x6',
                                label='5x6',
                                status='ingebruik',
                                definitie='5x6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5x6'),
        '6x25-16': KeuzelijstWaarde(invulwaarde='6x25-16',
                                    label='6x25+16',
                                    status='ingebruik',
                                    definitie='6x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/6x25-16'),
        '7g2.5': KeuzelijstWaarde(invulwaarde='7g2.5',
                                  label='7G2.5',
                                  status='ingebruik',
                                  definitie='7G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/7g2.5'),
        '7x1.5': KeuzelijstWaarde(invulwaarde='7x1.5',
                                  label='7x1.5',
                                  status='ingebruik',
                                  definitie='7x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/7x1.5'),
        'zonder-bijkomende-specificatie': KeuzelijstWaarde(invulwaarde='zonder-bijkomende-specificatie',
                                                           label='zonder bijkomende specificatie',
                                                           status='uitgebruik',
                                                           definitie='uitgebruik',
                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/zonder-bijkomende-specificatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDraagconstructieDwarsdoorsnede(KeuzelijstField):
    """Lijst van mogelijke vormen van dwarsdoorsnedes van een draagconstructie."""
    naam = 'KlDraagconstructieDwarsdoorsnede'
    label = 'Draagconstructie dwarsdoorsnede'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDraagconstructieDwarsdoorsnede'
    definition = 'Lijst van mogelijke vormen van dwarsdoorsnedes van een draagconstructie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDraagconstructieDwarsdoorsnede'
    options = {
        'heptagonaal': KeuzelijstWaarde(invulwaarde='heptagonaal',
                                        label='heptagonaal',
                                        status='ingebruik',
                                        definitie='heptagonaal',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagconstructieDwarsdoorsnede/heptagonaal'),
        'octagonaal': KeuzelijstWaarde(invulwaarde='octagonaal',
                                       label='octagonaal',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagconstructieDwarsdoorsnede/octagonaal'),
        'rond': KeuzelijstWaarde(invulwaarde='rond',
                                 label='rond',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagconstructieDwarsdoorsnede/rond'),
        'vierkant': KeuzelijstWaarde(invulwaarde='vierkant',
                                     label='vierkant',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDraagconstructieDwarsdoorsnede/vierkant')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod, ABC
from ...Datatypes.DtcAdres import DtcAdres, DtcAdresWaarden
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DteTekstblok import DteTekstblok, DteTekstblokWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from ...Datatypes.KwantWrdInMeterTAW import KwantWrdInMeterTAW, KwantWrdInMeterTAWWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Put(ABC):
    """Abstracte bedoeld om de verschillende soort putten onder te brengen en gemeenschappelijke eigenschappen over te dragen. De relaties worden overgedragen via de abstracte PutRelaties."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Put'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._adres = OTLAttribuut(field=DtcAdres,
                                   naam='adres',
                                   label='adres',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Put.adres',
                                   definition='Dichtstbijgelegen adres voor de put, het adres bestaat enkel uit de straatnaam indien het dichtstbijzijnde adres > 100m verwijderd is.',
                                   owner=self)

        self._diepte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='diepte',
                                    label='diepte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Put.diepte',
                                    definition='Het verschil tussen het maaiveldpeil en het laagste punt van de binnenkant van de put in meter.',
                                    owner=self)

        self._maaiveldpeil = OTLAttribuut(field=KwantWrdInMeterTAW,
                                          naam='maaiveldpeil',
                                          label='maaiveldpeil',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Put.maaiveldpeil',
                                          definition='De hoogte van het grondoppervlak in meter-TAW in het midden van het deksel van de put.',
                                          owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Put.technischeFiche',
                                             kardinaliteit_max='*',
                                             definition='De technische fiche van de put.',
                                             owner=self)

        self._toestandPut = OTLAttribuut(field=DteTekstblok,
                                         naam='toestandPut',
                                         label='toestand put',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Put.toestandPut',
                                         definition='Opmerkingen van de toestand en staat van de (verbindings-)put.',
                                         owner=self)

    @property
    def adres(self) -> DtcAdresWaarden:
        """Dichtstbijgelegen adres voor de put, het adres bestaat enkel uit de straatnaam indien het dichtstbijzijnde adres > 100m verwijderd is."""
        return self._adres.get_waarde()

    @adres.setter
    def adres(self, value):
        self._adres.set_waarde(value, owner=self)

    @property
    def diepte(self) -> KwantWrdInMeterWaarden:
        """Het verschil tussen het maaiveldpeil en het laagste punt van de binnenkant van de put in meter."""
        return self._diepte.get_waarde()

    @diepte.setter
    def diepte(self, value):
        self._diepte.set_waarde(value, owner=self)

    @property
    def maaiveldpeil(self) -> KwantWrdInMeterTAWWaarden:
        """De hoogte van het grondoppervlak in meter-TAW in het midden van het deksel van de put."""
        return self._maaiveldpeil.get_waarde()

    @maaiveldpeil.setter
    def maaiveldpeil(self, value):
        self._maaiveldpeil.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> List[DtcDocumentWaarden]:
        """De technische fiche van de put."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def toestandPut(self) -> DteTekstblokWaarden:
        """Opmerkingen van de toestand en staat van de (verbindings-)put."""
        return self._toestandPut.get_waarde()

    @toestandPut.setter
    def toestandPut(self, value):
        self._toestandPut.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod, ABC
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField


# Generated with OTLClassCreator. To modify: extend, do not edit
class ContainerBuis(ABC):
    """Abstracte voor het groeperen van eigenschappen en relaties van buisvormige container elementen. Dit zijn buizen die kabels of andere leidingen kunnen bevatten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ContainerBuis'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.8.0'

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omhult', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ContainerBuis', deprecated='2.3.0')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omhult', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Mantelbuis', deprecated='2.3.0')

        self._kleur = OTLAttribuut(field=StringField,
                                   naam='kleur',
                                   label='kleur',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ContainerBuis.kleur',
                                   usagenote='Klasse uit gebruik sinds versie 2.8.0 ',
                                   deprecated_version='2.8.0',
                                   kardinaliteit_max='*',
                                   definition='De kleur van de coating.',
                                   owner=self)

    @property
    def kleur(self) -> List[str]:
        """De kleur van de coating."""
        return self._kleur.get_waarde()

    @kleur.setter
    def kleur(self, value):
        self._kleur.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Proef import Proef
from ...Datatypes.KlLEACPerformantieklasse import KlLEACPerformantieklasse
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ProefPerformantieklasse(Proef, PuntGeometrie, LijnGeometrie, VlakGeometrie):
    """Proef die de performantie (bij impact) bepaalt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefPerformantieklasse'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.0.0'

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GetesteBeginconstructie', deprecated='2.0.0')

        self._performantieklasse = OTLAttribuut(field=KlLEACPerformantieklasse,
                                                naam='performantieklasse',
                                                label='performantieklasse',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefPerformantieklasse.performantieklasse',
                                                usagenote='Klasse uit gebruik sinds versie 2.0.0 ',
                                                deprecated_version='2.0.0',
                                                definition='De aanduiding hoe (performantie) de beginconstructie is getest.',
                                                owner=self)

    @property
    def performantieklasse(self) -> str:
        """De aanduiding hoe (performantie) de beginconstructie is getest."""
        return self._performantieklasse.get_waarde()

    @performantieklasse.setter
    def performantieklasse(self, value):
        self._performantieklasse.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMIVMeetpuntGebied(KeuzelijstField):
    """Mogelijke MIV meetpuntgebieden."""
    naam = 'KlMIVMeetpuntGebied'
    label = 'MIV meetpuntgebied'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlMIVMeetpuntGebied'
    definition = 'Mogelijke MIV meetpuntgebieden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMIVMeetpuntGebied'
    options = {
        'afrit': KeuzelijstWaarde(invulwaarde='afrit',
                                  label='afrit',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVMeetpuntGebied/afrit'),
        'hoofdweg': KeuzelijstWaarde(invulwaarde='hoofdweg',
                                     label='hoofdweg',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVMeetpuntGebied/hoofdweg'),
        'oprit': KeuzelijstWaarde(invulwaarde='oprit',
                                  label='oprit',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVMeetpuntGebied/oprit'),
        'spookstrook': KeuzelijstWaarde(invulwaarde='spookstrook',
                                        label='spookstrook',
                                        status='ingebruik',
                                        definitie='Een tweede meetpunt op dezelfde plaats in een tunnel (of net er buiten) om te kunnen tellen wanneer er omgekeerd gereden wordt op een rijstrook tijdens een tunnelsluiting.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVMeetpuntGebied/spookstrook'),
        'tunnel': KeuzelijstWaarde(invulwaarde='tunnel',
                                   label='tunnel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVMeetpuntGebied/tunnel')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BetonnenConstructieElement import BetonnenConstructieElement
from ...Classes.Abstracten.ConstructieElement import ConstructieElement
from ...Classes.Abstracten.ConstructieElementenGC import ConstructieElementenGC
from ...Datatypes.DtcAfmetingBxlxhInM import DtcAfmetingBxlxhInM, DtcAfmetingBxlxhInMWaarden
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlPlaatsingswijzePlint import KlPlaatsingswijzePlint
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class PlintGC(BetonnenConstructieElement, ConstructieElement, ConstructieElementenGC, LijnGeometrie):
    """Een plint is een betonnen balk/plaat die de akoestische dichtheid verzekert tussen de schermelementen van de geluidswerende constructie en de bodem."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PlintGC'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pictogram')

        self._afmetingen = OTLAttribuut(field=DtcAfmetingBxlxhInM,
                                        naam='afmetingen',
                                        label='afmetingen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PlintGC.afmetingen',
                                        definition='Met dit complex datatype worden de afmetingen van de plint weergegeven. Indien de plint afwijkt van een rechthoekige vorm wordt deze informatie in de technische fiche opgeslagen.',
                                        owner=self)

        self._plaatsingswijze = OTLAttribuut(field=KlPlaatsingswijzePlint,
                                             naam='plaatsingswijze',
                                             label='plaatsingswijze',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PlintGC.plaatsingswijze',
                                             definition='De manier waarop de plint geplaatst is ten opzichte van de profielen.',
                                             owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PlintGC.technischeFiche',
                                             definition='Document met verdere specificaties van de plint die niet opgevangen worden met de aanwezige attributen.',
                                             owner=self)

    @property
    def afmetingen(self) -> DtcAfmetingBxlxhInMWaarden:
        """Met dit complex datatype worden de afmetingen van de plint weergegeven. Indien de plint afwijkt van een rechthoekige vorm wordt deze informatie in de technische fiche opgeslagen."""
        return self._afmetingen.get_waarde()

    @afmetingen.setter
    def afmetingen(self, value):
        self._afmetingen.set_waarde(value, owner=self)

    @property
    def plaatsingswijze(self) -> str:
        """De manier waarop de plint geplaatst is ten opzichte van de profielen."""
        return self._plaatsingswijze.get_waarde()

    @plaatsingswijze.setter
    def plaatsingswijze(self, value):
        self._plaatsingswijze.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Document met verdere specificaties van de plint die niet opgevangen worden met de aanwezige attributen."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLichtsensorMerk(KeuzelijstField):
    """Lichtsensor merken."""
    naam = 'KlLichtsensorMerk'
    label = 'Lichtsensor merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLichtsensorMerk'
    definition = 'Lichtsensor merken.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLichtsensorMerk'
    options = {
        'schreder': KeuzelijstWaarde(invulwaarde='schreder',
                                     label='Schreder',
                                     status='ingebruik',
                                     definitie='Schreder',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtsensorMerk/schreder')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Detectie import Detectie
from ...Classes.Abstracten.FirmwareObject import FirmwareObject
from ...Datatypes.KlWeggebondendetectorDetectieprincipe import KlWeggebondendetectorDetectieprincipe
from ...Datatypes.KlWeggebondendetectorMerk import KlWeggebondendetectorMerk
from ...Datatypes.KlWeggebondendetectorModelnaam import KlWeggebondendetectorModelnaam
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class WeggebondenDetector(Detectie, FirmwareObject, PuntGeometrie):
    """Weggebonden detectoren zijn draadloze in het wegdek geïntegreerde radars of magnetische inductiesensoren. Ze zitten ingebed in een cilinder, die geplaatst wordt in het wegdek en die draadloos communiceert met een access point die met de verkeersregelaar verbonden is"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WeggebondenDetector'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')

        self._detectieprincipe = OTLAttribuut(field=KlWeggebondendetectorDetectieprincipe,
                                              naam='detectieprincipe',
                                              label='detectieprincipe',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WeggebondenDetector.detectieprincipe',
                                              definition='Het detectieprincipe geeft aan hoe de weggebonden detector voertuigen detecteert, bv. door gebruik te maken van inductie of doppler.',
                                              owner=self)

        self._merk = OTLAttribuut(field=KlWeggebondendetectorMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WeggebondenDetector.merk',
                                  definition='Merknaam van een weggebonden detector.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlWeggebondendetectorModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WeggebondenDetector.modelnaam',
                                       definition='De modelnaam van een weggebonden detector.',
                                       owner=self)

    @property
    def detectieprincipe(self) -> str:
        """Het detectieprincipe geeft aan hoe de weggebonden detector voertuigen detecteert, bv. door gebruik te maken van inductie of doppler."""
        return self._detectieprincipe.get_waarde()

    @detectieprincipe.setter
    def detectieprincipe(self, value):
        self._detectieprincipe.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Merknaam van een weggebonden detector."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van een weggebonden detector."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod
from ...Classes.Abstracten.SteunStandaard import SteunStandaard


# Generated with OTLClassCreator. To modify: extend, do not edit
class VRIDraagconstructie(SteunStandaard):
    """Abstracte voor een dragend element (bv. paal, kolom ) waaraan lantaarns met verkeerslichten bevestigd kunnen worden bij de verkeersregelinstallatie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VRIDraagconstructie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Combilantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DetectieCamera')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Drukknop')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Fietslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Knipperlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpenbaarVervoerslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Radar')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voertuiglantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voetgangerslantaarn')



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSleutelplan(KeuzelijstField):
    """Een keuzelijst met verschillende types van sleutel."""
    naam = 'KlSleutelplan'
    label = 'Sleutelplan'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSleutelplan'
    definition = 'Een keuzelijst met verschillende types van sleutel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSleutelplan'
    options = {
        'dender': KeuzelijstWaarde(invulwaarde='dender',
                                   label='dender',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleutelplan/dender'),
        'digitaal': KeuzelijstWaarde(invulwaarde='digitaal',
                                     label='digitaal',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleutelplan/digitaal'),
        'isio': KeuzelijstWaarde(invulwaarde='isio',
                                 label='isio',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleutelplan/isio'),
        'type-a': KeuzelijstWaarde(invulwaarde='type-a',
                                   label='type A',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleutelplan/type-a'),
        'type-b': KeuzelijstWaarde(invulwaarde='type-b',
                                   label='type B',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleutelplan/type-b'),
        'uniek': KeuzelijstWaarde(invulwaarde='uniek',
                                  label='uniek',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleutelplan/uniek'),
        'yale-5': KeuzelijstWaarde(invulwaarde='yale-5',
                                   label='yale 5',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSleutelplan/yale-5')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

